==> jc-1.4.0.tar.gz: javax/swing/JList__242.h <==
// final class javax.swing.JList$2

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 160e17470c19298a javax_swing_AbstractListModel
// @dep_class 35cb330e78e74d72 javax_swing_JList__242

// header file dependencies
// @dep_header javax_swing_AbstractListModel

#include "javax/swing/AbstractListModel.h"

#ifndef _JC_javax_swing_JList__242_H_
#define _JC_javax_swing_JList__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_JList$object;

// Typedefs
typedef struct _jc_javax_swing_JList__242$sub_refs	_jc_javax_swing_JList__242$sub_refs;
typedef struct _jc_javax_swing_JList__242$sub_nonrefs	_jc_javax_swing_JList__242$sub_nonrefs;
typedef struct _jc_javax_swing_JList__242$refs	_jc_javax_swing_JList__242$refs;
typedef struct _jc_javax_swing_JList__242$nonrefs	_jc_javax_swing_JList__242$nonrefs;
typedef struct _jc_javax_swing_JList__242$object	_jc_javax_swing_JList__242$object;

typedef const struct _jc_javax_swing_JList__242$vmethods	_jc_javax_swing_JList__242$vmethods;
typedef const struct _jc_javax_swing_JList__242$vtable	_jc_javax_swing_JList__242$vtable;
typedef const struct _jc_javax_swing_JList__242$vtype	_jc_javax_swing_JList__242$vtype;

// Constructors
extern void _jc_javax_swing_JList__242$method$_init$6ae096a25838f233(_jc_env *, struct _jc_javax_swing_JList__242$object *, struct _jc_javax_swing_JList$object *, struct _jc_object_array *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_javax_swing_JList__242$method$getElementAt$be8cb7de3c95b82f(_jc_env *, struct _jc_javax_swing_JList__242$object *, jint);
extern jint _jc_javax_swing_JList__242$method$getSize$82f1d9ee1217ad91(_jc_env *, struct _jc_javax_swing_JList__242$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JList__242$method_info$getElementAt$be8cb7de3c95b82f;
extern _jc_method _jc_javax_swing_JList__242$method_info$getSize$82f1d9ee1217ad91;

// Virtual methods structure
struct _jc_javax_swing_JList__242$vmethods {
	struct _jc_java_lang_Object$object	*(*getElementAt$be8cb7de3c95b82f)(_jc_env *, struct _jc_javax_swing_JList__242$object *, jint);
	jint	(*getSize$82f1d9ee1217ad91)(_jc_env *, struct _jc_javax_swing_JList__242$object *);
};

// Vtable
struct _jc_javax_swing_JList__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractListModel$vmethods	javax_swing_AbstractListModel;
	_jc_javax_swing_JList__242$vmethods	javax_swing_JList__242;
};

// Vtype
struct _jc_javax_swing_JList__242$vtype {
	_jc_type			type;
	_jc_javax_swing_JList__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JList__242$sub_refs {
	struct _jc_javax_swing_JList$object	*this;
	_jc_object_array	*val__24listData;
};

// Reference instance fields (object)
struct _jc_javax_swing_JList__242$refs {
    _jc_javax_swing_JList__242$sub_refs	javax_swing_JList__242;
    _jc_javax_swing_AbstractListModel$sub_refs	javax_swing_AbstractListModel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JList__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JList__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractListModel$sub_nonrefs	javax_swing_AbstractListModel;
    _jc_javax_swing_JList__242$sub_nonrefs	javax_swing_JList__242;
};

// Object instance structure
struct _jc_javax_swing_JList__242$object {
	_jc_javax_swing_JList__242$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JList__242$vtype	*vtype;
	_jc_javax_swing_JList__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JList__242$vtype _jc_javax_swing_JList__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JList__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JList__242$class_object;

#endif	/* _JC_javax_swing_JList__242_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JList__242.h <==
// final class javax.swing.JList$2

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 160e17470c19298a javax_swing_AbstractListModel
// @dep_class 35cb330e78e74d72 javax_swing_JList__242

// header file dependencies
// @dep_header javax_swing_AbstractListModel

#include "javax/swing/AbstractListModel.h"

#ifndef _JC_javax_swing_JList__242_H_
#define _JC_javax_swing_JList__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_JList$object;

// Typedefs
typedef struct _jc_javax_swing_JList__242$sub_refs	_jc_javax_swing_JList__242$sub_refs;
typedef struct _jc_javax_swing_JList__242$sub_nonrefs	_jc_javax_swing_JList__242$sub_nonrefs;
typedef struct _jc_javax_swing_JList__242$refs	_jc_javax_swing_JList__242$refs;
typedef struct _jc_javax_swing_JList__242$nonrefs	_jc_javax_swing_JList__242$nonrefs;
typedef struct _jc_javax_swing_JList__242$object	_jc_javax_swing_JList__242$object;

typedef const struct _jc_javax_swing_JList__242$vmethods	_jc_javax_swing_JList__242$vmethods;
typedef const struct _jc_javax_swing_JList__242$vtable	_jc_javax_swing_JList__242$vtable;
typedef const struct _jc_javax_swing_JList__242$vtype	_jc_javax_swing_JList__242$vtype;

// Constructors
extern void _jc_javax_swing_JList__242$method$_init$6ae096a25838f233(_jc_env *, struct _jc_javax_swing_JList__242$object *, struct _jc_javax_swing_JList$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_javax_swing_JList__242$method$getElementAt$be8cb7de3c95b82f(_jc_env *, struct _jc_javax_swing_JList__242$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_JList__242$method$getSize$82f1d9ee1217ad91(_jc_env *, struct _jc_javax_swing_JList__242$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JList__242$method_info$getElementAt$be8cb7de3c95b82f;
extern _jc_method _jc_javax_swing_JList__242$method_info$getSize$82f1d9ee1217ad91;

// Virtual methods structure
struct _jc_javax_swing_JList__242$vmethods {
	struct _jc_java_lang_Object$object	*(*getElementAt$be8cb7de3c95b82f)(_jc_env *, struct _jc_javax_swing_JList__242$object *, jint) _JC_JCNI_ATTR;
	jint	(*getSize$82f1d9ee1217ad91)(_jc_env *, struct _jc_javax_swing_JList__242$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JList__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractListModel$vmethods	javax_swing_AbstractListModel;
	_jc_javax_swing_JList__242$vmethods	javax_swing_JList__242;
};

// Vtype
struct _jc_javax_swing_JList__242$vtype {
	_jc_type			type;
	_jc_javax_swing_JList__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JList__242$sub_refs {
	struct _jc_javax_swing_JList$object	*this;
	_jc_object_array	*val__24listData;
};

// Reference instance fields (object)
struct _jc_javax_swing_JList__242$refs {
    _jc_javax_swing_JList__242$sub_refs	javax_swing_JList__242;
    _jc_javax_swing_AbstractListModel$sub_refs	javax_swing_AbstractListModel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JList__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JList__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractListModel$sub_nonrefs	javax_swing_AbstractListModel;
    _jc_javax_swing_JList__242$sub_nonrefs	javax_swing_JList__242;
};

// Object instance structure
struct _jc_javax_swing_JList__242$object {
	_jc_javax_swing_JList__242$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JList__242$vtype	*vtype;
	_jc_javax_swing_JList__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JList__242$vtype _jc_javax_swing_JList__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JList__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JList__242$class_object;

#endif	/* _JC_javax_swing_JList__242_H_ */
